@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.5.1
+Version : 1.5.2
 Author  : Stefano Covino
-Date    : 04/11/2011
+Date    : 22/01/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -29,7 +29,8 @@ History : (27/09/2010) First version.
         : (20/11/2010) Better header formatting.
         : (31/12/2010) Minor bug correction.
         : (26/08/2011) Consistency check for unreliable CRVAL1,2 and CDELT1,2.
-        : (04/11/2011) Moer flexibility in header coordinate format.
+        : (04/11/2011) More flexibility in header coordinate format.
+        : (22/01/2012) Check that at least one catalogue returns data.
 """
 
 
@@ -249,12 +250,14 @@ class Astrometry:
                 cat = USNO(cntfld[0], cntfld[1], math.floor(radius))
             else:
                 cat = USNO(cntfld[0], cntfld[1], math.floor(radius))
-            cat.GetData()
-            cat.sort()
-            if len(cat.ListEntries) >= maxentr:
-                self.CatList = cat.ListEntries[:maxentr]
-            else:
-                self.CatList = cat.ListEntries    
+            #
+            if cat != None:
+                cat.GetData()
+                cat.sort()
+                if len(cat.ListEntries) >= maxentr:
+                    self.CatList = cat.ListEntries[:maxentr]
+                else:
+                    self.CatList = cat.ListEntries    
 
 
     def DefineWCSHeader(self):
