@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Math
-Version : 1.0.3
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 11/02/2012
+Date    : 23/08/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -18,11 +18,12 @@ History : (29/09/2010) First named version.
         : (09/02/2012) Sidereal time, hour and parallactic angles computation added.
         : (11/02/2012) PointMatch added.
         : (18/02/2012) Sky functions moved to SRPSky.
+        : (23/08/2012) New angular distance function.
 """
 
 
 __all__ = ['AngularDistance', 'AstroAngleInput', 'AstroCoordInput', 'AstroMagInput', 'CartesiamCoordAmpRotoTranslation', 
-            'CartesianDistance', 'InverseCartesiamCoordAmpRotoTranslation', 'MinDist', 'PointClass', 'PointMatch', 
-            'TriangleClass', 'TriangleMatch']
+            'CartesianDistance', 'CartesianVectorClass', 'FastAngularDistance', 'InverseCartesiamCoordAmpRotoTranslation', 
+            'MinDist', 'PointClass', 'PointMatch', 'TriangleClass', 'TriangleMatch']
 
 
