@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Spectroscopy
-Version : 1.3.1
+Version : 1.4.0
 Author  : Stefano Covino
-Date    : 27/10/2011
+Date    : 22/08/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -16,14 +16,15 @@ History : (17/11/2010) First named version.
         : (05/09/2011) Various constants and functions.
         : (23/10/2011) Flux density conversion.
         : (27/10/2011) FWHM variation with airmass and wavelength
+        : (22/08/2012) Atmospheric extinction curves
 """
 
 
-__all__ = ['Air2Vacuum', 'CalzettiExt', 'DLACrossSection', 'Ecm2sA2Jy', 'ExtConstants', 'FWHMvsZL', 'getAbs', 
-    'I_Totani', 'Jy2Ecm2sA', 'LymAlphaDumpConst', 'LyAlphaProfile', 'Ralpha', 'SolarAbundance', 'StndCriticalDens', 
-    'TauDLA', 'TauDLAVoigt', 'TauGP', 'TauIGM', 'TauVoigt', 'Transitions', 'Vacuum2Air', 'VoigtFunct', 
-    'VoigtFunctApprox', 'VoigtFunctApproxA', 'VoigtFunctTG', 'VoigtFunctWells', 'VoigtIntegrand', 'VoigtProfileCmpd', 
-    'VoigtProfileWells']
+__all__ = ['Air2Vacuum', 'AirRefrIndex', 'AtmExtinction', 'CalzettiExt', 'DLACrossSection', 'Ecm2sA2Jy', 'ExtConstants', 
+    'FWHMvsZL', 'getAbs', 'I_Totani', 'Jy2Ecm2sA', 'LymAlphaDumpConst', 'LyAlphaProfile', 'OzonVertExt', 'RaleyghScattering', 
+    'Ralpha', 'SolarAbundance', 'StndCriticalDens', 'TauDLA', 'TauDLAVoigt', 'TauGP', 'TauIGM', 'TauVoigt', 'Transitions', 
+    'Vacuum2Air', 'VoigtFunct', 'VoigtFunctApprox', 'VoigtFunctApproxA', 'VoigtFunctTG', 'VoigtFunctWells', 
+    'VoigtIntegrand', 'VoigtProfileCmpd', 'VoigtProfileWells']
 
 
 import math
@@ -82,4 +83,9 @@ AbsOscillStrength       = 0.4162
 ClassLymAlphaDumpConst  = (8*math.pi**2*ElectronCharge**2)/(3*ElectronMass*SpeedofLight*LambdaLymanAlpha**2)
 
 
+# Atmospheric extinction curves
+CP  =   'Paranal'
+LP  =   'LaPalma'
+LS  =   'LaSilla'
 
+AtmExtCurves = {CP : 'Paranal.dat', LP : 'LaPalma.dat', LS : 'LaSilla.dat'}
