@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : System
-Version : 1.0.2
+Version : 1.0.3
 Author  : Stefano Covino
-Date    : 05/02/2012
+Date    : 15/06/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -13,10 +13,11 @@ Usage   : to be imported
 History : (24/08/2011) First named version.
         : (02/10/2011) List of Fits files function.
         : (05/02/2012) Solid path.
+        : (15/06/2012) New function
 """
 
 
 
-__all__ = ['ListDirTimeSorted', 'ListOfFitsFiles', 'Pipe', 'SRPPath', 
-            'Touch', 'Which']
+__all__ = ['HowOldIsFile', 'ListDirTimeSorted', 'ListOfFitsFiles', 'Pipe', 
+            'SRPPath', 'Touch', 'Which']
 
