@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.53
+Version : 1.0.58
 Author  : Stefano Covino
-Date    : 21/05/2012
+Date    : 28/08/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -71,6 +71,11 @@ History : (28/09/2010) First named version.
         : (21/03/2012) V. 3.10.5b4.
         : (20/05/2012) V. 3.10.5b5.
         : (21/05/2012) V. 3.10.5.
+        : (27/05/2012) V. 3.10.6b1.
+        : (15/06/2012) V. 3.10.6b2.
+        : (17/06/2012) V. 3.10.6b3.
+        : (31/07/2012) V. 3.10.6b4.
+        : (28/08/2012) V. 3.10.6.
 """
 
 
@@ -85,5 +90,5 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.5'
+__version__ = '3.10.6'
 
